/*
 * Level.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Level.h"

namespace ZoomEdit {
namespace Data {

Level::Level(xmlpp::Element *levelNode) : info(dynamic_cast<xmlpp::Element*>(levelNode->get_children("info").front())) {
  roomsNode = dynamic_cast<xmlpp::Element*>(levelNode->get_children("rooms").front());
  gatesNode = dynamic_cast<xmlpp::Element*>(levelNode->get_children("gates").front());
  texturesNode = dynamic_cast<xmlpp::Element*>(levelNode->get_children("textures").front());
  
  xmlpp::Node::NodeList nodeList = roomsNode->get_children("room");
  
  for(xmlpp::Node::NodeList::iterator room = nodeList.begin(); room != nodeList.end(); ++room) {
    xmlpp::Element *roomNode = dynamic_cast<xmlpp::Element*>(*room);
    
    if(roomNode)
      rooms.push_front(Room(roomNode));
  }
  
  nodeList = gatesNode->get_children("gate");
  
  for(xmlpp::Node::NodeList::iterator gate = nodeList.begin(); gate != nodeList.end(); ++gate) {
    xmlpp::Element *gateNode = dynamic_cast<xmlpp::Element*>(*gate);
    
    if(gateNode)
      gates.push_front(Gate(gateNode));
  }
  
  nodeList = texturesNode->get_children("texture");
  
  for(xmlpp::Node::NodeList::iterator tex = nodeList.begin(); tex != nodeList.end(); ++tex) {
    xmlpp::Element *texNode = dynamic_cast<xmlpp::Element*>(*tex);
    
    if(texNode)
      textures.push_front(Texture(texNode));
  }
}

}
}
